import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';
//importing the properties from the d3
const svg = select('svg'); //svg provides options to draw different shapes such as Lines, Rectangles, Circles.
// creating width and height for the svg diagram
const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => { //To render a React element into a root DOM node
  const title = 'People visited to from 2010 to 2019'; // giving title for my line chart 
  
  const xValue = d => +d.year; //displaying the x values ie years 1999 to 2013
  const xAxisLabel = 'year'; // labeling the x axis as year

  const yValue = d => d.visitors; // displaying the y values ie from 10 million to 100 million 
  const yAxisLabel = 'visitors'; // labeling the y axis as electronic sales
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };// providing the margin for line chart using css properties
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  //container
  
  const xScale = scaleTime()
  //complete set of values
    .domain(extent(data, xValue)) //returns the minimum and maximum value in an array from the given array using natural order.
    .range([0,innerWidth]) //output bounds
    .nice(); // it will round the values out
  
  const yScale = scaleLinear() // 
    .domain([0, max(data, yValue )])
    .range([innerHeight,0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);//center g in svg
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight) // to get axis position at bottom
    .tickPadding(20);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth) // to get axis position at left side
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis); //It appends a 'g' element to the SVG. g element is used to group SVG shapes together,
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text') // for labeling the text
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'grey')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text') // for x axis labeling
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'blue')
      .text(xAxisLabel);
  
  const lineGenerator = line() // it generrates horizantal and vertical lines for x and y axis
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); //coordinates in pixels
  
  g.append('path') // provides path to the line 
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
    console.log(lineGenerator(data))
  
  g.append('text') // for labeling the title
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};
// getting the csv data uisng github url link for my data 
csv('https://gist.githubusercontent.com/Saikiran2029/3344b72c598b7906335c2814632aeb76/raw/e3f8715e3f419baaf7b3612981f2eb8735051e03/year.csv')
  .then(data => {
  	//console.log(data)
    data.forEach(d => {
    	d.ESales = +d.ESales;
      d.Year = new Date(d.Year)
    });
  console.log(data)
    render(data);
  });